# R Project
#
# Janine Campbell
# Contact: janineinchile@gmail.com
#
# Date last modified: 17 November 2020
#
###############################################################################
# Before running the is code, follow these instructions
#     1. Save all files (R code files and .csv data files) in the same folder
#        on your computer
#     2. Change the working directory (line 31) to the folder where you have
#        saved the code and data
#     3. Code should then run
###############################################################################
#
###############################################################################
# Crisp Set Analysis with COMBINEDPISA data set
###############################################################################
#
#------------------------------------------------------------------------------
# Remove all objects surrently stored in active memory
#------------------------------------------------------------------------------
rm(list=ls(all=TRUE))
# rm means remove, and it can also be used for an individual condition/variable
#------------------------------------------------------------------------------
# Check / set working directory
#------------------------------------------------------------------------------
getwd()
# Check that working directory is correct.  To change use following code:
#setwd("ADDRESS_OF_DIRECTORY") 
options(prompt="R> ")
#------------------------------------------------------------------------------
# Save Script with an original name 
#------------------------------------------------------------------------------
#
#    *****Manually save script*****
#
#------------------------------------------------------------------------------
# Activate packages for session
#------------------------------------------------------------------------------
library(readr)
library(QCA)
library(SetMethods)
library(ggplot2)
library(ggthemes)
#
#------------------------------------------------------------------------------
# Import csv file
#------------------------------------------------------------------------------
COMBINEDPISA <- read.csv("COMBINEDPISA.csv", row.names = 1)
head(COMBINEDPISA)
#
#------------------------------------------------------------------------------
# Calibrate Data
#------------------------------------------------------------------------------
#
# Check cases in each of the outcome conditions (already coded in csv file)
#
rownames(COMBINEDPISA)[COMBINEDPISA$HIPISA==1]
#
rownames(COMBINEDPISA)[COMBINEDPISA$LOPISA==1]
#
rownames(COMBINEDPISA)[COMBINEDPISA$MIDPISA==1]
#
# Calibrate data into crisp sets
#
# Simplify GDPCAP into thousands (to reduce large labels on graphs etc)
COMBINEDPISA$GDPCAP<-COMBINEDPISA$GDPCAP/1000
#
# Calibrate sets with OECD average as cutoff
COMBINEDPISA$LOPOP <- ifelse(COMBINEDPISA$POP<34848,1,0)
COMBINEDPISA$HIGDPCAP <- ifelse(COMBINEDPISA$GDPCAP>38.88,1,0)
COMBINEDPISA$HIINCEQ <- ifelse(COMBINEDPISA$ININEQ<5.89,1,0)
COMBINEDPISA$HIDEM <- ifelse(COMBINEDPISA$DEM>8.13,1,0)
COMBINEDPISA$HIHDI <- ifelse(COMBINEDPISA$HDI>0.888,1,0)
COMBINEDPISA$LOGENINEQ <- ifelse(COMBINEDPISA$GENINEQ<0.123,1,0)
COMBINEDPISA$LOGENGAP <- ifelse(COMBINEDPISA$GENGAP>0.744,1,0)
COMBINEDPISA$HIECOFREE <- ifelse(COMBINEDPISA$ECOFREE>71.3,1,0)
COMBINEDPISA$LOIMM <- ifelse(COMBINEDPISA$IMM<7.3,1,0)
COMBINEDPISA$LOETHNICFRAC <- ifelse(COMBINEDPISA$ETHNICFRAC<0.25,1,0)
COMBINEDPISA$LOLANGFRAC <- ifelse(COMBINEDPISA$LANGFRAC<0.2345,1,0)
COMBINEDPISA$LORELFRAC <- ifelse(COMBINEDPISA$RELFRAC<0.4187,1,0)
#
COMBINEDPISA$HIPOWER <- ifelse(COMBINEDPISA$POWER>50,1,0)
COMBINEDPISA$HIINDIV <- ifelse(COMBINEDPISA$INDIV>50,1,0)
COMBINEDPISA$HICOMPET <- ifelse(COMBINEDPISA$COMPET>50,1,0)
COMBINEDPISA$HIUNCERT <- ifelse(COMBINEDPISA$UNCERT>50,1,0)
COMBINEDPISA$HILONG <- ifelse(COMBINEDPISA$LONG>50,1,0)
COMBINEDPISA$HIINDULG <- ifelse(COMBINEDPISA$INDULG>50,1,0)
#
# Remove raw data from data frame
COMBINEDPISA <- COMBINEDPISA[,-c(2:19)]
#
#------------------------------------------------------------------------------
# Create condition HIGENEQ with "or" as gender conditions are functional equivalents
#------------------------------------------------------------------------------
#
COMBINEDPISA$HIGENEQ <- ifelse(COMBINEDPISA$LOGENINEQ==1 | COMBINEDPISA$LOGENGAP==1,1,0)
# 
# Remove original conditions from data frame
COMBINEDPISA <- COMBINEDPISA[,-c(11:12)]
#
#------------------------------------------------------------------------------
# Save .csv data file with calibrated crisp sets
#------------------------------------------------------------------------------
#
write.csv(COMBINEDPISA, "CRISPCOMBINED.csv")
#
#------------------------------------------------------------------------------
# Analysis of necessity for HIPISA
#------------------------------------------------------------------------------
#
# Load csv file for crisp set conditions
CRISPCOMBINED <- read.csv("CRISPCOMBINED.csv", row.names = 1)
head(CRISPCOMBINED)
#
# Remove culture conditions
CRISPCOMBINED <- CRISPCOMBINED[,-c(16:21)]
head(CRISPCOMBINED)
#
# Testing all conditions in one command against HIPISA 
QCAfit(CRISPCOMBINED[,6:16], CRISPCOMBINED$HIPISA, necessity = TRUE, names(CRISPCOMBINED[,6:16]))
#
# Conduct a SUIN analysis
SUINHIPISA<-superSubset(CRISPCOMBINED[,3:16], outcome = "HIPISA", 
                  conditions = "LOPOP, HIINCEQ, HIDEM, HIHDI, HIECOFREE, LOIMM, LOETHNICFRAC, 
                  LOLANGFRAC, LORELFRAC, HIGENEQ",
                  neg.out = FALSE, relation = "nec",
                  incl.cut=0.95, cov.cut=0.6, ron.cut=0.6, use.tilde = TRUE)
SUINHIPISA
#
#------------------------------------------------------------------------------
# Analysis of Necessity for LOPISA
#------------------------------------------------------------------------------
#
# Testing all conditions in one command against LOPISA 
QCAfit(CRISPCOMBINED[,6:16], CRISPCOMBINED$LOPISA, necessity = TRUE, names(CRISPCOMBINED[,6:16]))
#
# Conduct a SUIN analysis
SUINLOPISA<-superSubset(CRISPCOMBINED[,3:16], outcome = "LOPISA", 
                        conditions = "LOPOP, HIINCEQ, HIDEM, HIHDI, HIECOFREE, LOIMM, LOETHNICFRAC, 
                        LOLANGFRAC, LORELFRAC, HIGENEQ",
                        neg.out = FALSE, relation = "nec",
                        incl.cut=0.95, cov.cut=0.6, ron.cut=0.6, use.tilde = TRUE)
SUINLOPISA
#
# Compare results for HIPISA and LOPISA
SUINHIPISA
SUINLOPISA
#
#########################################################################
# RESULTS                                                               #
#                                                                       #
# Conditions that repeat:    HIGENEQ-necessary alone in both directions #
#                            LOETHNICFRAC-SUIN CONDITION HIPISA         #
#                            HIINCEQ-SUIN CONDITION HIPISA              #
#                            HIHDI-SUIN CONDITION both directions       #
#                            LOIMM-SUIN CONDITION both directions       #
#                                                                       #
#########################################################################
#
#******************************************************************************
# ANALYSIS OF CULTURAL CONDITIONS 
#******************************************************************************
#
#------------------------------------------------------------------------------
# Analysis of necessity for HIPISA
#------------------------------------------------------------------------------
#
# Load csv file for crisp set conditions
CRISPCOMBINED <- read.csv("CRISPCOMBINED.csv", row.names = 1)
head(CRISPCOMBINED)
#
# Remove macro conditions
CRISPCOMBINED <- CRISPCOMBINED[,-c(6:15)]
CRISPCOMBINED <- CRISPCOMBINED[,-c(12)]
head(CRISPCOMBINED)
#
# Testing all conditions in one command against HIPISA 
QCAfit(CRISPCOMBINED[,6:11], CRISPCOMBINED$HIPISA, necessity = TRUE, names(CRISPCOMBINED[,6:11]))
#
# Conduct a SUIN analysis
SUINHIPISA<-superSubset(CRISPCOMBINED[,3:11], outcome = "HIPISA", 
                        conditions = "HIPOWER, HIINDIV, HICOMPET, HIUNCERT, HILONG, HIINDULG",
                        neg.out = FALSE, relation = "nec",
                        incl.cut=0.95, cov.cut=0.5, ron.cut=0.6, use.tilde = TRUE)
# no combinations
#SUINHIPISA
#
#------------------------------------------------------------------------------
# Analysis of Necessity for LOPISA
#------------------------------------------------------------------------------
#
# Testing all conditions in one command against LOPISA 
QCAfit(CRISPCOMBINED[,6:11], CRISPCOMBINED$LOPISA, necessity = TRUE, names(CRISPCOMBINED[,6:11]))
#
# Conduct a SUIN analysis
SUINLOPISA<-superSubset(CRISPCOMBINED[,3:11], outcome = "LOPISA", 
                        conditions = "HIPOWER, HIINDIV, HICOMPET, HIUNCERT, HILONG, HIINDULG",
                        neg.out = FALSE, relation = "nec",
                        incl.cut=0.95, cov.cut=0.55, ron.cut=0.6, use.tilde = TRUE)
SUINLOPISA
#
#
#########################################################################
# RESULTS                                                               #
#                                                                       #
# Possible interesting conditions that repeat:                          #
#                            HIINDIV-SUIN LOPISA                        #
#                            HIPOWER-SUIN LOPISA                        #
#                                                                       #
#########################################################################
#
#
#******************************************************************************
# COMBINED ANALYSIS WITH MOST INTERESTING MACRO AND CULTURAL CONDITIONS
#******************************************************************************
#
# Load csv file for crisp set conditions
CRISPCOMBINED <- read.csv("CRISPCOMBINED.csv", row.names = 1)
head(CRISPCOMBINED)
#
# Remove unwanted conditions
CRISPCOMBINED <- CRISPCOMBINED[,-c(2)]
CRISPCOMBINED <- CRISPCOMBINED[,-c(5)]
CRISPCOMBINED <- CRISPCOMBINED[,-c(7)]
CRISPCOMBINED <- CRISPCOMBINED[,-c(8)]
CRISPCOMBINED <- CRISPCOMBINED[,-c(10:11)]
CRISPCOMBINED <- CRISPCOMBINED[,-c(12:15)]
CRISPCOMBINED <- CRISPCOMBINED[,-c(5)]
head(CRISPCOMBINED)
#
# Testing all conditions in one command against HIPISA 
QCAfit(CRISPCOMBINED[,5:11], CRISPCOMBINED$HIPISA, necessity = TRUE, names(CRISPCOMBINED[,5:11]))
#
# Conduct a SUIN analysis
SUINHIPISA<-superSubset(CRISPCOMBINED[,2:11], outcome = "HIPISA", 
                        conditions = "HIPOWER, HIINDIV, HIINCEQ, HIHDI,
                        HIGENEQ, LOETHNICFRAC, LOIMM",
                        neg.out = FALSE, relation = "nec",
                        incl.cut=0.95, cov.cut=0.60, ron.cut=0.6, use.tilde = TRUE)
SUINHIPISA
#
#------------------------------------------------------------------------------
# Analysis of Necessity for LOPISA
#------------------------------------------------------------------------------
#
# Testing all conditions in one command against LOPISA 
QCAfit(CRISPCOMBINED[,5:11], CRISPCOMBINED$LOPISA, necessity = TRUE, names(CRISPCOMBINED[,5:11]))
#
# Conduct a SUIN analysis
SUINLOPISA<-superSubset(CRISPCOMBINED[,2:11], outcome = "LOPISA", 
                        conditions = "HIINDIV, HIINCEQ, HIHDI,
                        HIGENEQ, LOETHNICFRAC, LOIMM",
                        neg.out = FALSE, relation = "nec",
                        incl.cut=0.95, cov.cut=0.6, ron.cut=0.6, use.tilde = TRUE)
SUINLOPISA
#
SUINHIPISA
#
#------------------------------------------------------------------------------
# Test conditions for sufficiency with HIPISA (using SUIN solutions for HIPISA)
#------------------------------------------------------------------------------
#
# THE FULL ITERATIVE ANALYSES ARE NOT REPRODUCED HERE, JUST THE TRUTH TABLES FOR
# SOLUTION TERMS THAT WERE IDENTIFIED BY THESE ANALYSES
#
#
TTSOLHIPISA1<-truthTable(CRISPCOMBINED, outcome = "HIPISA", conditions = "HIGENEQ, HIINCEQ, 
                   HIINDIV", incl.cut = .80, sort.by = c("out", "inc", "n"), n.cut = 1, 
                        complete=TRUE, show.cases=T)
TTSOLHIPISA1
#
# Solution HIGENEQ * HIINCEQ * HIINDIV
#
#
TTSOLHIPISA2<-truthTable(CRISPCOMBINED, outcome = "HIPISA", conditions = "HIGENEQ, HIHDI, 
                        HIINDIV", incl.cut = .80, sort.by = c("out", "inc", "n"), n.cut = 1, 
                        complete=TRUE, show.cases=T)
TTSOLHIPISA2
#
# Solution HIGENEQ * HIHDI * ~HIINDIV
#   
# CASES not covered by solution terms AUS, POL, PRT
# INCONSISTENT CASES AUT, ISL, CHE
#
#------------------------------------------------------------------------------
# Test conditions for sufficiency with LOPISA
#------------------------------------------------------------------------------
#
TTSOLLOPISA<-truthTable(CRISPCOMBINED, outcome = "LOPISA", conditions = "HIGENEQ,
                   HIINDIV, HIHDI", 
                      incl.cut = .80, sort.by = c("out", "inc", "n"), n.cut = 1, 
                      complete=TRUE, show.cases = T)
TTSOLLOPISA
#
#
# Solution ~HIGENEQ * ~HIHDI * ~HIINDIV
#
# CASES not covered by solution terms 0
# INCONSISTENT CASES HRV, RUS, VNM
#
#
#------------------------------------------------------------------------------
# Explore how many other countries in meet the conditions for the solutions
# DATA SET: ALL, number of cases 83 total
#------------------------------------------------------------------------------
#
ALL <- read.csv("COMBINEDALL.csv", row.names = 1)
head(ALL)
#
# Eliminate columns not needed for analysis
ALL <- ALL[,-c(2:5)]
head(ALL)
#
# Calibrate data
#
ALL$HIINCEQ <- ifelse(ALL$ININEQ<5.89,1,0)
ALL$HIHDI <- ifelse(ALL$HDI>0.888,1,0)
ALL$LOGENINEQ <- ifelse(ALL$GENINEQ<0.123,1,0)
ALL$LOGENGAP <- ifelse(ALL$GENGAP>0.744,1,0)
ALL$HIINDIV <- ifelse(ALL$INDIV>50,1,0)
#
# Remove raw data from data frame
ALL <- ALL[,-c(2:6)]
head(ALL)
#
# Create condition GENEQ as gender conditions are functional equivalents
ALL$HIGENEQ <- ifelse(ALL$LOGENINEQ==1 | ALL$LOGENGAP==1,1,0)
# 
# Remove original conditions from data frame
ALL <- ALL[,-c(4:5)]
head(ALL)
#
# Review number of countries for each solutions term
# 
# HIPISA
#
# HIGENEQ*HIINCEQ*HIINDIV
rownames(ALL)[ALL$HIGENEQ==1 & ALL$HIINCEQ==1 & ALL$HIINDIV==1]
# only 16 countries, the same countries as original analysis,
# no more countries with same configuration
#
# HIGENEQ*HIHDI*~HIINDIV
rownames(ALL)[ALL$HIGENEQ==1 & ALL$HIHDI==1 & ALL$HIINDIV==0]
# only 4 countries, the same countries as original analysis, 
# no more countries with same configuration
#
# LOPISA
#
# ~HIGENEQ*~HIINDIV*~HIHDI
rownames(ALL)[ALL$HIGENEQ==0 & ALL$HIINDIV==0]
# 45 countries (54% of all countries with data), only 16 countries in original analysis, 
# 29 (of the 34 additional countries for which data is available) have the same configuration
#
#
#------------------------------------------------------------------------------
# Save Script
#------------------------------------------------------------------------------
#
#    *****Manually save script*****
#
#------------------------------------------------------------------------------
# Quit R
#------------------------------------------------------------------------------
q()


